@@ -134,6 +134,8 @@ Creating linear models
 \-  lti/set                     set/modify properties of LTI models
 \-  setdelaymodel               specify internal delay model (state space
                                 only)
+\*  :func:`rss`                 create a random continuous state space model
+\*  :func:`drss`                create a random discrete state space model
 ==  ==========================  ============================================
 
 
@@ -141,7 +143,7 @@ Data extraction
 ----------------------------------------------------------------------------
 
 ==  ==========================  ============================================
-\   lti/tfdata                  extract numerators and denominators
+\*  :func:`tfdata`              extract numerators and denominators
 \   lti/zpkdata                 extract zero/pole/gain data
 \   lti/ssdata                  extract state-space matrices
 \   lti/dssdata                 descriptor version of SSDATA
@@ -159,7 +161,7 @@ Conversions
 \   zpk                         conversion to zero/pole/gain
 \*  :func:`ss`                  conversion to state space
 \*  :func:`frd`                 conversion to frequency data
-\   c2d                         continuous to discrete conversion
+\*  :func:`c2d`                 continuous to discrete conversion
 \   d2c                         discrete to continuous conversion
 \   d2d                         resample discrete-time model
 \   upsample                    upsample discrete-time LTI systems
@@ -183,7 +185,7 @@ System interconnections
                                 (see also overloaded ``*``)
 \*  :func:`~bdalg.feedback`     connect lti models with a feedback loop
 \   lti/lft                     generalized feedback interconnection
-\   lti/connect                 arbitrary interconnection of lti models
+\*  :func:'~bdalg.connect'      arbitrary interconnection of lti models
 \   sumblk                      summing junction (for use with connect)
 \   strseq                      builds sequence of indexed strings
                                 (for I/O naming)
@@ -1111,6 +1113,17 @@ def rlocus(sys, klist = None, **keywords):
     klist:
         optional list of gains
 
+    Keyword parameters
+    ------------------
+    xlim : control of x-axis range, normally with tuple, for
+        other options, see matplotlib.axes
+    ylim : control of y-axis range
+    Plot : boolean (default = True)
+        If True, plot magnitude and phase
+    PrintGain: boolean (default = True)
+        If True, report mouse clicks when close to the root-locus branches,
+        calculate gain, damping and print
+
     Returns
     -------
     rlist:
@@ -1269,10 +1282,11 @@ def step(sys, T=None, X0=0., input=0, output=None, **keywords):
     '''
     Step response of a linear system
 
-    If the system has multiple inputs or outputs (MIMO), one input and one
-    output have to be selected for the simulation. The parameters `input`
-    and `output` do this. All other inputs are set to 0, all other outputs
-    are ignored.
+    If the system has multiple inputs or outputs (MIMO), one input has
+    to be selected for the simulation.  Optionally, one output may be
+    selected. If no selection is made for the output, all outputs are
+    given. The parameters `input` and `output` do this. All other
+    inputs are set to 0, all other outputs are ignored.
 
     Parameters
     ----------
@@ -1291,7 +1305,7 @@ def step(sys, T=None, X0=0., input=0, output=None, **keywords):
         Index of the input that will be used in this simulation.
 
     output: int
-        Index of the output that will be used in this simulation.
+        If given, index of the output that is returned by this simulation.
 
     **keywords:
         Additional keyword arguments control the solution algorithm for the
@@ -1321,14 +1335,15 @@ def step(sys, T=None, X0=0., input=0, output=None, **keywords):
                                    transpose = True, **keywords)
     return yout, T
 
-def impulse(sys, T=None, input=0, output=0, **keywords):
+def impulse(sys, T=None, input=0, output=None, **keywords):
     '''
     Impulse response of a linear system
 
-    If the system has multiple inputs or outputs (MIMO), one input and
-    one output must be selected for the simulation. The parameters
-    `input` and `output` do this. All other inputs are set to 0, all
-    other outputs are ignored.
+    If the system has multiple inputs or outputs (MIMO), one input has
+    to be selected for the simulation.  Optionally, one output may be
+    selected. If no selection is made for the output, all outputs are
+    given. The parameters `input` and `output` do this. All other
+    inputs are set to 0, all other outputs are ignored.
 
     Parameters
     ----------
@@ -1371,15 +1386,14 @@ def impulse(sys, T=None, input=0, output=0, **keywords):
                                    transpose = True, **keywords)
     return yout, T
 
-def initial(sys, T=None, X0=0., input=0, output=0, **keywords):
+def initial(sys, T=None, X0=0., input=None, output=None, **keywords):
     '''
     Initial condition response of a linear system
-
-    If the system has multiple inputs or outputs (MIMO), one input and one
-    output have to be selected for the simulation. The parameters `input`
-    and `output` do this. All other inputs are set to 0, all other outputs
-    are ignored.
-
+    
+    If the system has multiple outputs (?IMO), optionally, one output
+    may be selected. If no selection is made for the output, all
+    outputs are given.
+    
     Parameters
     ----------
     sys: StateSpace, or TransferFunction
@@ -1394,10 +1408,11 @@ def initial(sys, T=None, X0=0., input=0, output=0, **keywords):
         Numbers are converted to constant arrays with the correct shape.
 
     input: int
-        Index of the input that will be used in this simulation.
+        This input is ignored, but present for compatibility with step
+        and impulse.
 
     output: int
-        Index of the output that will be used in this simulation.
+        If given, index of the output that is returned by this simulation.
 
     **keywords:
         Additional keyword arguments control the solution algorithm for the
@@ -1422,9 +1437,10 @@ def initial(sys, T=None, X0=0., input=0, output=0, **keywords):
     Examples
     --------
     >>> T, yout = initial(sys, T, X0)
+
     '''
-    T, yout = timeresp.initial_response(sys, T, X0, input, output,
-                                   transpose = True, **keywords)
+    T, yout = timeresp.initial_response(sys, T, X0, output=output,
+                                        transpose=True, **keywords)
     return yout, T
 
 def lsim(sys, U=0., T=None, X0=0., **keywords):
@@ -1524,8 +1540,29 @@ def tfdata(sys, **kw):
     return (tf.num, tf.den)
 
 # Convert a continuous time system to a discrete time system
-def c2d(sysc, Ts, method):
-    # TODO: add docstring
+def c2d(sysc, Ts, method='zoh'):
+    '''
+    Return a discrete-time system
+
+    Parameters
+    ----------
+    sysc: Lti (StateSpace or TransferFunction), continuous
+        System to be converted
+
+    Ts: number
+        Sample time for the conversion
+
+    method: string, optional
+        Method to be applied, 
+        'zoh'        Zero-order hold on the inputs (default)
+        'foh'        First-order hold, currently not implemented
+        'impulse'    Impulse-invariant discretization, currently not implemented
+        'tustin'     Bilinear (Tustin) approximation, only SISO
+        'matched'    Matched pole-zero method, only SISO
+    '''
     #  Call the sample_system() function to do the work
-    return sample_system(sysc, Ts, method)
+    sysd = sample_system(sysc, Ts, method)
+    if isinstance(sysc, StateSpace) and not isinstance(sysd, StateSpace):
+        return _convertToStateSpace(sysd)
+    return sysd
 
