@@ -2,7 +2,8 @@
 """
 Time domain simulation.
 
-This file contains a collection of functions that calculate time responses for linear systems.
+This file contains a collection of functions that calculate
+time responses for linear systems.
 
 .. _time-series-convention:
 
@@ -118,12 +119,12 @@ $Id$
 import scipy as sp              # SciPy library (used all over)
 import numpy as np              # NumPy library
 from scipy.signal.ltisys import _default_response_times
-from copy import deepcopy
 import warnings
 from .lti import Lti     # base class of StateSpace, TransferFunction
-from .statesp import StateSpace, _rss_generate, _convertToStateSpace, _mimo2simo, _mimo2siso
+from .statesp import _convertToStateSpace, _mimo2simo, _mimo2siso
 from .lti import isdtime, isctime
 
+
 # Helper function for checking array-like parameters
 def _check_convert_array(in_obj, legal_shapes, err_msg_start, squeeze=False,
                          transpose=False):
@@ -173,23 +174,23 @@ def _check_convert_array(in_obj, legal_shapes, err_msg_start, squeeze=False,
     out_array: array
         The checked and converted contents of ``in_obj``.
     """
-    #convert nearly everything to an array.
+    # convert nearly everything to an array.
     out_array = np.asarray(in_obj)
     if (transpose):
         out_array = np.transpose(out_array)
 
-    #Test element data type, elements must be numbers
-    legal_kinds = set(("i", "f", "c")) #integer, float, complex
+    # Test element data type, elements must be numbers
+    legal_kinds = set(("i", "f", "c"))  # integer, float, complex
     if out_array.dtype.kind not in legal_kinds:
         err_msg = "Wrong element data type: '{d}'. Array elements " \
                   "must be numbers.".format(d=str(out_array.dtype))
         raise TypeError(err_msg_start + err_msg)
 
-    #If array is zero dimensional (in_obj is scalar):
-    #create array with legal shape filled with the original value.
+    # If array is zero dimensional (in_obj is scalar):
+    # create array with legal shape filled with the original value.
     if out_array.ndim == 0:
         for s_legal in legal_shapes:
-            #search for shape that does not contain the special symbol any.
+            # search for shape that does not contain the special symbol any.
             if "any" in s_legal:
                 continue
             the_val = out_array[()]
@@ -197,13 +198,13 @@ def _check_convert_array(in_obj, legal_shapes, err_msg_start, squeeze=False,
             out_array.fill(the_val)
             break
 
-    #Test shape
+    # Test shape
     def shape_matches(s_legal, s_actual):
         """Test if two shape tuples match"""
-        #Array must have required number of dimensions
+        # Array must have required number of dimensions
         if len(s_legal) != len(s_actual):
             return False
-        #All dimensions must contain required number of elements. Joker: "all"
+        # All dimensions must contain required number of elements. Joker: "all"
         for n_legal, n_actual in zip(s_legal, s_actual):
             if n_legal == "any":
                 continue
@@ -211,7 +212,7 @@ def _check_convert_array(in_obj, legal_shapes, err_msg_start, squeeze=False,
                 return False
         return True
 
-    #Iterate over legal shapes, and see if any matches out_array's shape.
+    # Iterate over legal shapes, and see if any matches out_array's shape.
     for s_legal in legal_shapes:
         if shape_matches(s_legal, out_array.shape):
             break
@@ -221,15 +222,16 @@ def _check_convert_array(in_obj, legal_shapes, err_msg_start, squeeze=False,
                   .format(e=legal_shape_str, a=str(out_array.shape))
         raise ValueError(err_msg_start + err_msg)
 
-    #Convert shape
+    # Convert shape
     if squeeze:
         out_array = np.squeeze(out_array)
-        #We don't want zero dimensional arrays
+        # We don't want zero dimensional arrays
         if out_array.shape == tuple():
             out_array = out_array.reshape((1,))
 
     return out_array
 
+
 # Forced response of a linear system
 def forced_response(sys, T=None, U=0., X0=0., transpose=False, **keywords):
     """Simulate the output of a linear system.
@@ -292,15 +294,15 @@ def forced_response(sys, T=None, U=0., X0=0., transpose=False, **keywords):
                         '(For example ``StateSpace`` or ``TransferFunction``)')
     sys = _convertToStateSpace(sys)
     A, B, C, D = np.asarray(sys.A), np.asarray(sys.B), np.asarray(sys.C), \
-                 np.asarray(sys.D)
+        np.asarray(sys.D)
 #    d_type = A.dtype
     n_states = A.shape[0]
     n_inputs = B.shape[1]
 
     # Set and/or check time vector in discrete time case
     if isdtime(sys, strict=True):
-        if T == None:
-            if U == None:
+        if T is None:
+            if U is None:
                 raise ValueError('Parameters ``T`` and ``U`` can\'t both be'
                                  'zero for discrete-time simulation')
             # Set T to integers with same length as U
@@ -318,28 +320,28 @@ def forced_response(sys, T=None, U=0., X0=0., transpose=False, **keywords):
     if T is None:
         raise ValueError('Parameter ``T``: must be array-like, and contain '
                          '(strictly monotonic) increasing numbers.')
-    T = _check_convert_array(T, [('any',), (1,'any')],
+    T = _check_convert_array(T, [('any',), (1, 'any')],
                              'Parameter ``T``: ', squeeze=True,
-                             transpose = transpose)
+                             transpose=transpose)
     if not all(T[1:] - T[:-1] > 0):
         raise ValueError('Parameter ``T``: time values must be '
                          '(strictly monotonic) increasing numbers.')
     n_steps = len(T)            # number of simulation steps
 
-    #create X0 if not given, test if X0 has correct shape
-    X0 = _check_convert_array(X0, [(n_states,), (n_states,1)],
+    # create X0 if not given, test if X0 has correct shape
+    X0 = _check_convert_array(X0, [(n_states,), (n_states, 1)],
                               'Parameter ``X0``: ', squeeze=True)
 
     # Separate out the discrete and continuous time cases
     if isctime(sys):
         # Solve the differential equation, copied from scipy.signal.ltisys.
-        dot, squeeze, = np.dot, np.squeeze #Faster and shorter code
+        dot, squeeze, = np.dot, np.squeeze  # Faster and shorter code
 
         # Faster algorithm if U is zero
         if U is None or (isinstance(U, (int, float)) and U == 0):
             # Function that computes the time derivative of the linear system
             def f_dot(x, _t):
-                return dot(A,x)
+                return dot(A, x)
 
             xout = sp.integrate.odeint(f_dot, X0, T, **keywords)
             yout = dot(C, xout.T)
@@ -347,14 +349,14 @@ def forced_response(sys, T=None, U=0., X0=0., transpose=False, **keywords):
         # General algorithm that interpolates U in between output points
         else:
             # Test if U has correct shape and type
-            legal_shapes = [(n_steps,), (1,n_steps)] if n_inputs == 1 else \
+            legal_shapes = [(n_steps,), (1, n_steps)] if n_inputs == 1 else \
                            [(n_inputs, n_steps)]
             U = _check_convert_array(U, legal_shapes,
                                      'Parameter ``U``: ', squeeze=False,
                                      transpose=transpose)
             # convert 1D array to D2 array with only one row
             if len(U.shape) == 1:
-                U = U.reshape(1,-1)                      #pylint: disable=E1103
+                U = U.reshape(1, -1)  # pylint: disable=E1103
 
             # Create a callable that uses linear interpolation to
             # calculate the input at any time.
@@ -365,7 +367,7 @@ def forced_response(sys, T=None, U=0., X0=0., transpose=False, **keywords):
 
             # Function that computes the time derivative of the linear system
             def f_dot(x, t):
-                return dot(A,x) + squeeze(dot(B,compute_u([t])))
+                return dot(A, x) + squeeze(dot(B, compute_u([t])))
 
             xout = sp.integrate.odeint(f_dot, X0, T, **keywords)
             yout = dot(C, xout.T) + dot(D, U)
@@ -386,9 +388,10 @@ def forced_response(sys, T=None, U=0., X0=0., transpose=False, **keywords):
 
     return T, yout, xout
 
+
 def step_response(sys, T=None, X0=0., input=0, output=None,
-                  transpose = False, **keywords):
-    #pylint: disable=W0622
+                  transpose=False, **keywords):
+    # pylint: disable=W0622
     """Step response of a linear system
 
     If the system has multiple inputs or outputs (MIMO), one input has
@@ -448,7 +451,7 @@ def step_response(sys, T=None, X0=0., input=0, output=None,
     >>> T, yout = step_response(sys, T, X0)
     """
     sys = _convertToStateSpace(sys)
-    if output == None:
+    if output is None:
         sys = _mimo2simo(sys, input, warn_conversion=True)
     else:
         sys = _mimo2siso(sys, input, output, warn_conversion=True)
@@ -468,15 +471,14 @@ def step_response(sys, T=None, X0=0., input=0, output=None,
     return T, yout
 
 
-def initial_response(sys, T=None, X0=0., input=0, output=None, transpose=False,
-                     **keywords):
-    #pylint: disable=W0622
+def initial_response(sys, T=None, X0=0., input=0, output=None,
+                     transpose=False, **keywords):
+    # pylint: disable=W0622
     """Initial condition response of a linear system
 
-    If the system has multiple inputs or outputs (MIMO), one input and one
-    output have to be selected for the simulation. The parameters `input`
-    and `output` do this. All other inputs are set to 0, all other outputs
-    are ignored.
+    If the system has multiple outputs (MIMO), optionally, one output
+    may be selected. If no selection is made for the output, all
+    outputs are given.
 
     For information on the **shape** of parameters `T`, `X0` and
     return values `T`, `yout` see: :ref:`time-series-convention`
@@ -495,7 +497,8 @@ def initial_response(sys, T=None, X0=0., input=0, output=None, transpose=False,
         Numbers are converted to constant arrays with the correct shape.
 
     input: int
-        Index of the input that will be used in this simulation.
+        Ignored, has no meaning in initial condition calculation. Parameter
+        ensures compatibility with step_response and impulse_response
 
     output: int
         Index of the output that will be used in this simulation. Set to None
@@ -530,7 +533,7 @@ def initial_response(sys, T=None, X0=0., input=0, output=None, transpose=False,
     >>> T, yout = initial_response(sys, T, X0)
     """
     sys = _convertToStateSpace(sys)
-    if output == None:
+    if output is None:
         sys = _mimo2simo(sys, input, warn_conversion=False)
     else:
         sys = _mimo2siso(sys, input, output, warn_conversion=False)
@@ -547,14 +550,14 @@ def initial_response(sys, T=None, X0=0., input=0, output=None, transpose=False,
 
 
 def impulse_response(sys, T=None, X0=0., input=0, output=None,
-                    transpose=False, **keywords):
-    #pylint: disable=W0622
+                     transpose=False, **keywords):
+    # pylint: disable=W0622
     """Impulse response of a linear system
 
-    If the system has multiple inputs or outputs (MIMO), one input and one
-    output have to be selected for the simulation. The parameters `input`
-    and `output` do this. All other inputs are set to 0, all other outputs
-    are ignored.
+    If the system has multiple inputs or outputs (MIMO), one input has
+    to be selected for the simulation. Optionally, one output may be
+    selected. The parameters `input` and `output` do this. All other
+    inputs are set to 0, all other outputs are ignored.
 
     For information on the **shape** of parameters `T`, `X0` and
     return values `T`, `yout` see: :ref:`time-series-convention`
@@ -608,7 +611,7 @@ def impulse_response(sys, T=None, X0=0., input=0, output=None,
     >>> T, yout = impulse_response(sys, T, X0)
     """
     sys = _convertToStateSpace(sys)
-    if output == None:
+    if output is None:
         sys = _mimo2simo(sys, input, warn_conversion=True)
     else:
         sys = _mimo2siso(sys, input, output, warn_conversion=True)
@@ -622,7 +625,7 @@ def impulse_response(sys, T=None, X0=0., input=0, output=None,
     # create X0 if not given, test if X0 has correct shape.
     # Must be done here because it is used for computations here.
     n_states = sys.A.shape[0]
-    X0 = _check_convert_array(X0, [(n_states,), (n_states,1)],
+    X0 = _check_convert_array(X0, [(n_states,), (n_states, 1)],
                               'Parameter ``X0``: \n', squeeze=True)
 
     # Compute new X0 that contains the impulse
@@ -637,7 +640,7 @@ def impulse_response(sys, T=None, X0=0., input=0, output=None,
         T = _default_response_times(sys.A, 100)
     U = np.zeros_like(T)
 
-    T, yout, _xout  = forced_response(sys, T, U, new_X0, \
-                          transpose=transpose, **keywords)
+    T, yout, _xout = forced_response(
+        sys, T, U, new_X0,
+        transpose=transpose, **keywords)
     return T, yout
-
